@@ -85,12 +85,21 @@ static const QString & xdgConfigFolder()
 namespace KWinQtCurve
 {
 
+    // make the handler accessible to other classes...
+static QtCurveHandler *handler = 0;
+
+QtCurveHandler * Handler()
+{
+    return handler;
+}
+
 QtCurveHandler::QtCurveHandler()
               : itsLastMenuXid(0)
               , itsLastStatusXid(0)
               , itsStyle(NULL)
               , itsDBus(NULL)
 {
+    handler=this;
     setStyle();
     reset(0);
 
@@ -100,6 +109,7 @@ QtCurveHandler::QtCurveHandler()
 
 QtCurveHandler::~QtCurveHandler()
 {
+    handler=0;
     delete itsStyle;
 }
 
@@ -145,7 +155,7 @@ bool QtCurveHandler::reset(unsigned long changed)
         setStyle();
         styleChanged=true;
     }
-    
+
     // we assume the active font to be the same as the inactive font since the control
     // center doesn't offer different settings anyways.
     itsTitleFont = KDecoration::options()->font(true, false); // not small
@@ -254,7 +264,7 @@ bool QtCurveHandler::supports(Ability ability) const
         case AbilityProvidesShadow:
             return customShadows();
 #endif
-#if KDE_IS_VERSION(4, 3, 85)
+#if KDE_IS_VERSION(4, 3, 85) && !KDE_IS_VERSION(4, 8, 80)
         case AbilityClientGrouping:
             return grouping();
 #endif
@@ -302,7 +312,7 @@ bool QtCurveHandler::readConfig(bool compositingToggled)
         borderHack=false;
     }
     else if(compositingToggled && !itsConfig.outerBorder() &&
-           (itsConfig.borderSize()<QtCurveConfig::BORDER_TINY || 
+           (itsConfig.borderSize()<QtCurveConfig::BORDER_TINY ||
             (wStyle()->pixelMetric((QStyle::PixelMetric)QtC_WindowBorder, 0L, 0L)&WINDOW_BORDER_COLOR_TITLEBAR_ONLY)))
     {
         QDBusConnection::sessionBus().send(QDBusMessage::createSignal("/KWin", "org.kde.KWin", "reloadConfig"));
@@ -405,7 +415,7 @@ int QtCurveHandler::borderSize(bool bot) const
         else if(QtCurveConfig::BORDER_TINY==itsConfig.borderSize() && itsConfig.roundBottom() && itsConfig.outerBorder())
             return itsBorderSize+1;
     }
-    return itsBorderSize; 
+    return itsBorderSize;
 }
 
 void QtCurveHandler::borderSizeChanged()
@@ -454,7 +464,7 @@ void QtCurveHandler::emitToggleStatusBar(int xid)
 {
     itsDBus->emitSbToggle(xid);
 }
-    
+
 int QtCurveHandler::borderEdgeSize() const
 {
     return itsConfig.edgePad()+
@@ -476,25 +486,20 @@ void QtCurveHandler::removeClient(QtCurveClient *c)
         itsLastStatusXid=0;
     itsClients.removeAll(c);
 }
- 
-// make the handler accessible to other classes...
-static QtCurveHandler *handler = 0;
-
-QtCurveHandler * Handler()
-{
-    return handler;
-}
 
 }
 
+#if KDE_IS_VERSION(4, 9, 0)
+KWIN_DECORATION(KWinQtCurve::QtCurveHandler)
+#else
 extern "C"
 {
     KDE_EXPORT KDecorationFactory *create_factory()
     {
-        KWinQtCurve::handler = new KWinQtCurve::QtCurveHandler();
-        return KWinQtCurve::handler;
+        return new KWinQtCurve::QtCurveHandler();
     }
 }
+#endif
 
 #include "qtcurvedbus.moc"
 #include "qtcurvehandler.moc"
